<?php
/*
Plugin Name: SublimeVideo
Plugin URI: http://orthogonalcreartions.com/sublimevideo-plugin/
Description: This plugin will allow you to add the SublimeVideo player to your site. It will add the Javascript to the head of the site after you provide your player code and allows you to set a default width and height for the player as well as a default poster and preload setting. It also provides a shortcode for embedding the SublimeVideo player in a post or page. Usage is [sublimevideo width="#" height="#" posterurl="url" preload="option" mp4url="url" webmurl="url" oggurl="url"] and the only thing you must provide is a url for at least one video format.
Version: 1.0
Author: Jon Breitenbucher
Author URI: http://jon.breitenbucher.net
*/

/*
SublimeVideo (Wordpress Plugin)
Copyright (C) 2010 Jon Breitenbucher
Contact me at http://jon.breitenbucher.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

// create custom plugin settings menu
add_action('admin_menu', 'sublimevideo_create_menu');

function sublimevideo_create_menu() {
// create new menu in the Settings panel
	add_options_page('SublimeVideo Options', 'SublimeVideo', 'manage_options', 'sublimevideo_settings_page', 'sublimevideo_settings_page');

// call register settings function
	add_action( 'admin_init', 'register_mysettings' );
}


function register_mysettings() {
// register our settings
	register_setting( 'sublimevideo-settings-group', 'sublimevideo_playercode' );
	register_setting( 'sublimevideo-settings-group', 'sublimevideo_player_width' );
	register_setting( 'sublimevideo-settings-group', 'sublimevideo_player_height' );
	register_setting( 'sublimevideo-settings-group', 'sublimevideo_player_poster' );
	register_setting( 'sublimevideo-settings-group', 'sublimevideo_player_preload' );
}

// create the actual contents of the settings page
function sublimevideo_settings_page() {
	if (!current_user_can('manage_options'))  {
		wp_die( __('You do not have sufficient permissions to access this page.') );
	}
?>
<div class="wrap">
<h2>SublimeVideo Options</h2>

<form method="post" action="options.php">
    <?php settings_fields( 'sublimevideo-settings-group' ); ?>
    <table class="form-table">
        <tr valign="top">
        <th scope="row">Player Code</th>
        <td><input type="text" name="sublimevideo_playercode" value="<?php echo get_option('sublimevideo_playercode'); ?>" /> Provided by SublimeVideo at the end of the URL in your Embed Code.</td>
        </tr>
        
        <tr valign="top">
        <th scope="row"><h4>Player defaults</h4></th>
        <td>&nbsp;</td>
        </tr>
         
        <tr valign="top">
        <th scope="row">Default player width:</th>
        <td><input type="text" name="sublimevideo_player_width" value="<?php echo get_option('sublimevideo_player_width'); ?>" /> The default width of the video player if not set.</td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Default player height:</th>
        <td><input type="text" name="sublimevideo_player_height" value="<?php echo get_option('sublimevideo_player_height'); ?>" /> The default height of the video player if not set.</td>
        </tr>

				<tr valign="top">
        <th scope="row">Default poster image URL:</th>
        <td><input type="text" name="sublimevideo_player_poster" value="<?php echo get_option('sublimevideo_player_poster'); ?>" /> The default image displayed in the player window if not set.</td>
        </tr>

				<tr valign="top">
        <th scope="row">Default preload:</th>
        <td><input type="text" name="sublimevideo_player_preload" value="<?php echo get_option('sublimevideo_player_preload'); ?>" /> The default is none so that the videos are not preloaded. Other options are metadata and auto.</td>
        </tr>
    </table>
    
    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>

</form>
</div>
<?php } ?>
<?php
// insert the SublimeVideo javascript into the header
function sublimevideo_head() {
			$playercode = get_option('sublimevideo_playercode');
			echo '<script type="text/javascript" src="http://cdn.sublimevideo.net/js/' . $playercode . '"></script>';
		}

add_action('wp_head', 'sublimevideo_head');

// tell wordpress to register the sublimevideo shortcode
add_shortcode('sublimevideo', 'sublimevideo_function');

// function to process the shortcode
function sublimevideo_function($atts) {
  // extract the options
  extract(shortcode_atts(array(
			'width' => get_option('sublimevideo_player_width', '640'),
			'height' => get_option('sublimevideo_player_height', '360'),
			'poster' => get_option('sublimevideo_player_poster', ''),
			'preload' => get_option('sublimevideo_player_preload', 'none'),
			'mp4' => '',
			'webm' => '',
			'ogg' => '',
		), $atts));
  // send back text to calling function
  return '<video class="sublime" width="' . esc_attr($width) . '" height="' . esc_attr($height) . '" poster="' . esc_attr($poster) . '" preload="' . esc_attr($preload) . '"><source src="' . esc_attr($mp4) . '" type="video/mp4" /><source src="' . esc_attr($webm) . '" type="video/webm" /><source src="' . esc_attr($ogg) . '" type="video/ogg" /></video>';
}
?>